@@ -1,4 +1,4 @@
-import dataclasses
+from dataclasses import dataclass, field
 from typing import Union, TYPE_CHECKING
 
 from . import PersonStyle, GroupReferenceStyle, BracketStyle
@@ -11,15 +11,15 @@ if TYPE_CHECKING:
     from pybtex.richtext import BaseText
 
 
-@dataclasses.dataclass
+@dataclass
 class FootReferenceStyle(GroupReferenceStyle):
     """Textual or parenthetical reference using footnotes."""
 
     #: Bracket style for textual citations (:cite:t: and variations).
-    bracket_textual: BracketStyle = BracketStyle()
+    bracket_textual: BracketStyle = field(default_factory=BracketStyle)
 
     #: Person style (applies to all relevant citation commands).
-    person: PersonStyle = PersonStyle()
+    person: PersonStyle = field(default_factory=PersonStyle)
 
     #: Separator between text and reference for textual citations.
     text_reference_sep: Union["BaseText", str] = ''
