@@ -1,6 +1,3 @@
-import os
-import sys
-sys.path.append(os.path.dirname(__file__))
 extensions = [
     'sphinxcontrib.bibtex', 'sphinx.ext.autodoc']
 exclude_patterns = ['_build']
