@@ -1,23 +1,25 @@
-import dataclasses
+from dataclasses import dataclass, field
 import sphinxcontrib.bibtex.plugin
 
 from sphinxcontrib.bibtex.style.referencing import BracketStyle
 from sphinxcontrib.bibtex.style.referencing.author_year \
     import AuthorYearReferenceStyle
 
-my_bracket_style = BracketStyle(
-    left='(',
-    right=')',
-)
+
+def bracket_style() -> BracketStyle:
+    return BracketStyle(
+        left='(',
+        right=')',
+    )
 
 
-@dataclasses.dataclass
+@dataclass
 class MyReferenceStyle(AuthorYearReferenceStyle):
-    bracket_parenthetical: BracketStyle = my_bracket_style
-    bracket_textual: BracketStyle = my_bracket_style
-    bracket_author: BracketStyle = my_bracket_style
-    bracket_label: BracketStyle = my_bracket_style
-    bracket_year: BracketStyle = my_bracket_style
+    bracket_parenthetical: BracketStyle = field(default_factory=bracket_style)
+    bracket_textual: BracketStyle = field(default_factory=bracket_style)
+    bracket_author: BracketStyle = field(default_factory=bracket_style)
+    bracket_label: BracketStyle = field(default_factory=bracket_style)
+    bracket_year: BracketStyle = field(default_factory=bracket_style)
 
 
 sphinxcontrib.bibtex.plugin.register_plugin(
