@@ -6,11 +6,22 @@
 """
 
 from test.common import (
-    html_citation_refs, html_citations, html_footnote_refs, html_footnotes
+    html_citation_refs_single, html_citations, html_footnote_refs,
+    html_footnotes
 )
+import test.some_module_cite
+import test.some_module_footcite
 import pytest
 
 
+# for coverage
+def test_some_module() -> None:
+    f1 = test.some_module_cite.Foo(0)
+    assert f1.c == 3
+    f2 = test.some_module_footcite.Foo(0)
+    assert f2.c == 3
+
+
 @pytest.mark.sphinx('html', testroot='autodoc')
 def test_autodoc(app, warning) -> None:
     app.build()
@@ -21,14 +32,15 @@ def test_autodoc(app, warning) -> None:
     titles = ['Een', 'Twee', 'Drie', 'Vier', 'Vijf', 'Zes', 'Zeven', 'Acht',
               'Negen', 'Tien', 'Elf']
     for label, title in zip(labels, titles):
-        assert len(html_citation_refs(label=label).findall(output)) == 1
+        assert len(html_citation_refs_single(label=label).findall(output)) == 1
         assert len(html_citations(label=label).findall(output)) == 1
-        match_ref = html_citation_refs(label=label).search(output)
+        match_ref = html_citation_refs_single(label=label).search(output)
         match = html_citations(label=label).search(output)
         assert match_ref
         assert match
         assert match_ref.group('refid') == match.group('id_')
         assert title in match.group('text')
+        assert match_ref.group('id_') == match.group('backref')
     output2 = (app.outdir / "doc_footcite.html").read_text()
     assert len(html_footnote_refs().findall(output2)) == 11
     for title in titles:
