@@ -1,5 +1,10 @@
-from test.common import html_citations, html_citation_refs
-import dataclasses
+import pybtex.plugin
+from pybtex.style.formatting.unsrt import Style as UnsrtStyle
+from pybtex.style.template import words
+
+from test.common import html_citations, html_citation_refs, \
+    html_docutils_citation_refs
+from dataclasses import dataclass, field
 import pytest
 import re
 import sphinxcontrib.bibtex.plugin
@@ -251,33 +256,35 @@ def test_citation_style_invalid(make_app, app_params) -> None:
         make_app(*args, **kwargs)
 
 
-my_bracket = BracketStyle(
-    left='(',
-    right=')',
-    sep='; ',
-    sep2='; ',
-    last_sep='; ',
-)
+def my_bracket() -> BracketStyle:
+    return BracketStyle(
+        left='(',
+        right=')',
+        sep='; ',
+        sep2='; ',
+        last_sep='; ',
+    )
 
 
-my_person = PersonStyle(
-    style='last',
-    abbreviate=False,
-    sep=' & ',
-    sep2=None,
-    last_sep=None,
-    other=' et al',
-)
+def my_person() -> PersonStyle:
+    return PersonStyle(
+        style='last',
+        abbreviate=False,
+        sep=' & ',
+        sep2=None,
+        last_sep=None,
+        other=' et al',
+    )
 
 
-@dataclasses.dataclass
+@dataclass
 class CustomReferenceStyle(AuthorYearReferenceStyle):
-    bracket_textual: BracketStyle = my_bracket
-    bracket_parenthetical: BracketStyle = my_bracket
-    bracket_author: BracketStyle = my_bracket
-    bracket_label: BracketStyle = my_bracket
-    bracket_year: BracketStyle = my_bracket
-    person: PersonStyle = my_person
+    bracket_textual: BracketStyle = field(default_factory=my_bracket)
+    bracket_parenthetical: BracketStyle = field(default_factory=my_bracket)
+    bracket_author: BracketStyle = field(default_factory=my_bracket)
+    bracket_label: BracketStyle = field(default_factory=my_bracket)
+    bracket_year: BracketStyle = field(default_factory=my_bracket)
+    person: PersonStyle = field(default_factory=my_person)
     author_year_sep: str = ' '
 
 
@@ -361,3 +368,59 @@ def test_citation_style_round_brackets(app, warning) -> None:
     output = (app.outdir / "index.txt").read_text()
     assert "(Evensen, 2003)" in output
     assert "Evensen (2003)" in output
+
+
+@pytest.mark.sphinx('html', testroot='citation_toctree')
+def test_citation_toctree(app, warning) -> None:
+    app.build()
+    assert not warning.getvalue()
+    output = (app.outdir / "index.html").read_text()
+    output1 = (app.outdir / "adoc1.html").read_text()
+    output2 = (app.outdir / "adoc2.html").read_text()
+    assert len(html_citations(label='1').findall(output)) == 1
+    assert len(html_citation_refs(label='1').findall(output1)) == 1
+    assert len(html_docutils_citation_refs(
+        label=r'Test2').findall(output2)) == 1
+    assert len(html_citations(label='Test2').findall(output2)) == 1
+
+
+@pytest.mark.sphinx('html', testroot='debug_bibtex_citation')
+def test_citation_tooltip(app, warning) -> None:
+    app.build()
+    assert not warning.getvalue()
+    output = (app.outdir / "index.html").read_text()
+    assert len(html_citations(label='tes').findall(output)) == 1
+    assert len(html_citation_refs(
+        label='tes', title=r"The title\.").findall(output)) == 1
+
+
+@pytest.mark.sphinx('html', testroot='debug_bibtex_citation',
+                    confoverrides={'bibtex_tooltips': False})
+def test_citation_tooltip2(app, warning) -> None:
+    app.build()
+    assert not warning.getvalue()
+    output = (app.outdir / "index.html").read_text()
+    assert len(html_citations(label='tes').findall(output)) == 1
+    assert len(html_citation_refs(
+        label='tes', title=None).findall(output)) == 1
+
+
+class CustomTooltipStyle(UnsrtStyle):
+    def get_misc_template(self, e):
+        return words['whoop whoop']
+
+
+pybtex.plugin.register_plugin(
+    'pybtex.style.formatting', 'xxx_custom_tooltip_xxx', CustomTooltipStyle)
+
+
+@pytest.mark.sphinx('html', testroot='debug_bibtex_citation',
+                    confoverrides={
+                        'bibtex_tooltips_style': 'xxx_custom_tooltip_xxx'})
+def test_citation_tooltip3(app, warning) -> None:
+    app.build()
+    assert not warning.getvalue()
+    output = (app.outdir / "index.html").read_text()
+    assert len(html_citations(label='tes').findall(output)) == 1
+    assert len(html_citation_refs(
+        label='tes', title='whoop whoop').findall(output)) == 1
